@@ -1,3 +1,5 @@
+# type: ignore
+
 import pytest
 
 from mycli.packages.completion_engine import suggest_type
@@ -315,7 +317,7 @@ def test_sub_select_dot_col_name_completion():
 @pytest.mark.parametrize("join_type", ["", "INNER", "LEFT", "RIGHT OUTER"])
 @pytest.mark.parametrize("tbl_alias", ["", "foo"])
 def test_join_suggests_tables_and_schemas(tbl_alias, join_type):
-    text = "SELECT * FROM abc {0} {1} JOIN ".format(tbl_alias, join_type)
+    text = f"SELECT * FROM abc {tbl_alias} {join_type} JOIN "
     suggestion = suggest_type(text, text)
     assert sorted_dicts(suggestion) == sorted_dicts([{"type": "table", "schema": []}, {"type": "view", "schema": []}, {"type": "schema"}])
 
